# Changelog

## [1.6.1](https://github.com/vicwomg/pikaraoke/compare/1.6.0...1.6.1) (2024-12-02)


### Bug Fixes

* prevent hangs when volume change from exceeds max ([#429](https://github.com/vicwomg/pikaraoke/issues/429)) ([d097311](https://github.com/vicwomg/pikaraoke/commit/d0973114be53759f88a59d33112efffc72ebc6db))

## [1.6.0](https://github.com/vicwomg/pikaraoke/compare/1.5.2...1.6.0) (2024-11-23)


### Features

* Added support to Android via Termux App ([#423](https://github.com/vicwomg/pikaraoke/issues/423)) ([0118733](https://github.com/vicwomg/pikaraoke/commit/0118733d698263bc684829aeed69b3c589df43e5))

## [1.5.2](https://github.com/vicwomg/pikaraoke/compare/1.5.1...1.5.2) (2024-11-05)


### Bug Fixes

* admin passwords not working [#401](https://github.com/vicwomg/pikaraoke/issues/401) ([35550dc](https://github.com/vicwomg/pikaraoke/commit/35550dc858864aa928d5f25f75b57472826a11c0))
* broken upgrade path for --break-system-packages users ([9f01f23](https://github.com/vicwomg/pikaraoke/commit/9f01f23ebaabee2aa72b674ebe668d3247be571d))
* broken upgrade path for --break-system-packages users ([#395](https://github.com/vicwomg/pikaraoke/issues/395)) ([74c9dca](https://github.com/vicwomg/pikaraoke/commit/74c9dcaaf2d3a43bf93d4b179c2809be906855b5))
* Italian translation ([#415](https://github.com/vicwomg/pikaraoke/issues/415)) ([2c791c7](https://github.com/vicwomg/pikaraoke/commit/2c791c7f48129f84c9cf45dc2d857ad6742e4c0e))
* support orangepi devices as raspberry pi w/o hw accel ([658d381](https://github.com/vicwomg/pikaraoke/commit/658d381a82b0c87a321ab4f44d6eefea4bfb3bc0))

## [1.5.1](https://github.com/vicwomg/pikaraoke/compare/1.5.0...1.5.1) (2024-09-23)


### Bug Fixes

* 500 error when renaming while queued ([#399](https://github.com/vicwomg/pikaraoke/issues/399)) ([d84fcb3](https://github.com/vicwomg/pikaraoke/commit/d84fcb3ac8974a56e533c2bc3a2c2a58f91baee2))

## [1.5.0](https://github.com/vicwomg/pikaraoke/compare/1.4.1...1.5.0) (2024-09-04)


### Features

* add messages.mo file for es_VE translation ([3cd7d26](https://github.com/vicwomg/pikaraoke/commit/3cd7d2627f1e3ea2d44b482f896f9a6af750b1af))


### Bug Fixes

* song number overflows to add button when &gt; 999 songs [#379](https://github.com/vicwomg/pikaraoke/issues/379) ([a53c9e0](https://github.com/vicwomg/pikaraoke/commit/a53c9e00e144f5203bbecabe1a02f79dff739b68))


### Documentation

* move TROUBLESHOOTING to wiki ([331e814](https://github.com/vicwomg/pikaraoke/commit/331e814a5299189f5248c8595452af5985da3ef4))
* **readme:** recommend Bookworm OS over bullseye ([15598f2](https://github.com/vicwomg/pikaraoke/commit/15598f22e822e3c2014c63a866ecd3b72530698a))

## [1.4.1](https://github.com/vicwomg/pikaraoke/compare/1.4.0...1.4.1) (2024-09-03)


### Bug Fixes

* **ci:** missing long_description in build ([e5482b0](https://github.com/vicwomg/pikaraoke/commit/e5482b036dee906323aed876bed646237be0df5e))

## [1.4.0](https://github.com/vicwomg/pikaraoke/compare/v1.3.0...1.4.0) (2024-09-03)


### Features

* add a setup script ([2d0e973](https://github.com/vicwomg/pikaraoke/commit/2d0e973717892ec072afb0344a969f471e0400e9))
* create python package ([0c97670](https://github.com/vicwomg/pikaraoke/commit/0c97670bea36eb0f8affa17fd23212f64bbed6a7))
* upgrade yt-dlp on all pikaraoke runs ([fedd6ed](https://github.com/vicwomg/pikaraoke/commit/fedd6ed64e53a1e0fec4bc75368e767b57fa6b7e))


### Bug Fixes

* 287 bug: paths with spaces don't work ([f25e326](https://github.com/vicwomg/pikaraoke/commit/f25e32676066754c69f7bfb5b75b54c84ec7d866))
* modify files minimally to make it run ([168abbb](https://github.com/vicwomg/pikaraoke/commit/168abbb069412c1c2913a222623b0bfa0e5ccdf7))
* python-pygame name for apt installation ([be028ab](https://github.com/vicwomg/pikaraoke/commit/be028ab030f3a5a9e6463d9bcbabf6f957ea0dfe))
* resolve issues with commitlint attempt [#1](https://github.com/vicwomg/pikaraoke/issues/1) ([4c375e6](https://github.com/vicwomg/pikaraoke/commit/4c375e665f2333d527335e16d7db6093d96ed5a5))


### Documentation

* add conventional commits badge ([0c63c7d](https://github.com/vicwomg/pikaraoke/commit/0c63c7db4933bfe4549b19b04dc7a46a342039a6))
* rewrite README ([78df2e8](https://github.com/vicwomg/pikaraoke/commit/78df2e8bfc492c75d3befc09b777fdef8d4855fb))
